@@ -7,7 +7,7 @@ RDF::Query::Algebra::Extend - Algebra class for extending the variable projectio
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Extend version 2.917_01.
+This document describes RDF::Query::Algebra::Extend version 2.202, released 30 January 2010.
 
 =cut
 
@@ -28,16 +28,13 @@ use RDF::Trine::Iterator qw(sgrep);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.917_01';
+	$VERSION	= '2.202';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
@@ -100,7 +97,7 @@ sub vars {
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -142,6 +139,7 @@ sub _from_sse {
 			
 			if (m/^\s*[)]/) {
 				s/^\s*[)]\s*//;
+				warn "extend: " . Dumper(\@nodes);
 				return RDF::Query::Algebra::Extend->new( $pattern, \@nodes );
 			} else {
 				throw RDF::Trine::Error -text => "Cannot parse end-of-extend from SSE string: >>$_<<";
@@ -154,55 +152,30 @@ sub _from_sse {
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
 sub as_sparql {
 	my $self	= shift;
-	my $context	= shift || {};
+	my $context	= shift;
 	my $indent	= shift;
 	
-	if ($context->{ skip_extend }) {
-		$context->{ skip_extend }--;
-		return $self->pattern->as_sparql( $context, $indent );
-	}
-	
-	my $pattern	= $self->pattern;
 	my $vlist	= $self->vars;
 	my (@vars);
 	foreach my $k (@$vlist) {
 		if ($k->isa('RDF::Query::Expression')) {
-			push(@vars, $k->as_sparql({}, ''));
+			push(@vars, $k->sse({}, ''));
 		} elsif ($k->isa('RDF::Query::Node::Variable')) {
 			push(@vars, '?' . $k->name);
 		} else {
 			push(@vars, $k);
 		}
 	}
-	
-	my $ggp		= $pattern->as_sparql( $context, $indent );
-	my $sparql	= $ggp;
-	foreach my $v (@vars) {
-		$sparql	.=	"\n${indent}BIND" . $v;
-	}
-	return $sparql;
-}
-
-=item C<< as_hash >>
-
-Returns the query as a nested set of plain data structures (no objects).
-
-=cut
-
-sub as_hash {
-	my $self	= shift;
-	my $context	= shift;
-	return {
-		type 		=> lc($self->type),
-		pattern		=> $self->pattern->as_hash,
-		vars		=> [ map { $_->as_hash } @{ $self->vars } ],
-	};
+	my $pvars	= join(' ', map { '?' . $_ } sort $self->pattern->referenced_variables);
+	my $svars	= join(' ', sort @vars);
+	my $vars	= ($pvars eq $svars) ? '*' : join(' ', @vars);
+	return join(' ', $vars, 'WHERE', $self->pattern->as_sparql( $context, $indent ));
 }
 
 =item C<< type >>
@@ -234,22 +207,21 @@ sub referenced_variables {
 	return RDF::Query::_uniq(@vars);
 }
 
-=item C<< potentially_bound >>
+=item C<< binding_variables >>
 
 Returns a list of the variable names used in this algebra expression that will
 bind values during execution.
 
 =cut
 
-sub potentially_bound {
+sub binding_variables {
 	my $self	= shift;
-	my @vars;
-	push(@vars, $self->pattern->potentially_bound);
+	my @vars	= $self->pattern->binding_variables;
 	foreach my $v (@{ $self->vars }) {
 		if ($v->isa('RDF::Query::Node::Variable')) {
 			push(@vars, $v->name);
 		} else {
-			push(@vars, $v->potentially_bound);
+			push(@vars, $v->binding_variables);
 		}
 	}
 	return RDF::Query::_uniq(@vars);
