@@ -7,7 +7,7 @@ RDF::Query::Algebra::NamedGraph - Algebra class for NamedGraph patterns
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::NamedGraph version 2.201, released 30 January 2010.
+This document describes RDF::Query::Algebra::NamedGraph version 2.202, released 30 January 2010.
 
 =cut
 
@@ -29,7 +29,7 @@ use RDF::Trine::Iterator qw(sgrep smap swatch);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.201';
+	$VERSION	= '2.202';
 }
 
 ######################################################################
@@ -215,33 +215,6 @@ sub qualify_uris {
 }
 
 
-=item C<< fixup ( $query, $bridge, $base, \%namespaces ) >>
-
-Returns a new pattern that is ready for execution using the given bridge.
-This method replaces generic node objects with bridge-native objects.
-
-=cut
-
-sub fixup {
-	my $self	= shift;
-	my $class	= ref($self);
-	my $query	= shift;
-	my $bridge	= shift;
-	my $base	= shift;
-	my $ns		= shift;
-	
-	if (my $opt = $query->algebra_fixup( $self, $bridge, $base, $ns )) {
-		return $opt;
-	} else {
-		my $graph	= ($self->graph->isa('RDF::Query::Node'))
-					? $bridge->as_native( $self->graph )
-					: $self->graph->fixup( $query, $bridge, $base, $ns );
-		
-		my $pattern	= $self->pattern->fixup( $query, $bridge, $base, $ns );
-		return $class->new( $graph, $pattern );
-	}
-}
-
 1;
 
 __END__
