@@ -7,7 +7,7 @@ RDF::Query::Algebra::Not - Algebra class for Not patterns
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Not version 2.201, released 30 January 2010.
+This document describes RDF::Query::Algebra::Not version 2.202, released 30 January 2010.
 
 =cut
 
@@ -26,7 +26,7 @@ use RDF::Trine::Iterator qw(smap sgrep swatch);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.201';
+	$VERSION	= '2.202';
 }
 
 ######################################################################
@@ -165,29 +165,6 @@ sub definite_variables {
 	return $self->pattern->definite_variables;
 }
 
-=item C<< fixup ( $query, $bridge, $base, \%namespaces ) >>
-
-Returns a new pattern that is ready for execution using the given bridge.
-This method replaces generic node objects with bridge-native objects.
-
-=cut
-
-sub fixup {
-	my $self	= shift;
-	my $class	= ref($self);
-	my $query	= shift;
-	my $bridge	= shift;
-	my $base	= shift;
-	my $ns		= shift;
-
-	if (my $opt = $query->algebra_fixup( $self, $bridge, $base, $ns )) {
-		return $opt;
-	} else {
-		return $class->new( map { $_->fixup( $query, $bridge, $base, $ns ) } ($self->pattern, $self->not_pattern) );
-	}
-}
-
-
 1;
 
 __END__
