@@ -7,7 +7,7 @@ RDF::Query::Algebra::Project - Algebra class for projection
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Project version 2.201, released 30 January 2010.
+This document describes RDF::Query::Algebra::Project version 2.202, released 30 January 2010.
 
 =cut
 
@@ -20,7 +20,7 @@ use base qw(RDF::Query::Algebra);
 
 use Data::Dumper;
 use Set::Scalar;
-use Scalar::Util qw(blessed);
+use Scalar::Util qw(reftype blessed);
 use Carp qw(carp croak confess);
 use RDF::Trine::Iterator qw(sgrep);
 
@@ -28,7 +28,7 @@ use RDF::Trine::Iterator qw(sgrep);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.201';
+	$VERSION	= '2.202';
 }
 
 ######################################################################
@@ -49,7 +49,18 @@ sub new {
 	my $class	= shift;
 	my $pattern	= shift;
 	my $vars	= shift;
-	return bless( [ $pattern, $vars ], $class );
+	unless (reftype($vars) eq 'ARRAY' and not(blessed($vars))) {
+		throw RDF::Query::Error::MethodInvocationError -text => "Variable list in RDF::Query::Algebra::Project constructor must be an ARRAY reference";
+	}
+	my @vars;
+	foreach my $v (@$vars) {
+		if ($v->isa('RDF::Query::Node::Variable')) {
+			push(@vars, $v);
+		} else {
+			push(@vars, $v->alias);
+		}
+	}
+	return bless( [ $pattern, \@vars ], $class );
 }
 
 =item C<< construct_args >>
@@ -234,29 +245,6 @@ sub definite_variables {
 	return $self->pattern->definite_variables;
 }
 
-=item C<< fixup ( $query, $bridge, $base, \%namespaces ) >>
-
-Returns a new pattern that is ready for execution using the given bridge.
-This method replaces generic node objects with bridge-native objects.
-
-=cut
-
-sub fixup {
-	my $self	= shift;
-	my $class	= ref($self);
-	my $query	= shift;
-	my $bridge	= shift;
-	my $base	= shift;
-	my $ns		= shift;
-	
-	if (my $opt = $query->algebra_fixup( $self, $bridge, $base, $ns )) {
-		return $opt;
-	} else {
-		return $class->new( $self->pattern->fixup( $query, $bridge, $base, $ns ), $self->vars );
-	}
-}
-
-
 =item C<< is_solution_modifier >>
 
 Returns true if this node is a solution modifier.
