@@ -7,7 +7,7 @@ RDF::Query::Algebra::SubSelect - Algebra class for Subselects
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::SubSelect version 2.917_01.
+This document describes RDF::Query::Algebra::SubSelect version 2.202, released 30 January 2010.
 
 =cut
 
@@ -32,16 +32,13 @@ use RDF::Trine::Iterator qw(sgrep smap swatch);
 our ($VERSION, $BLOOM_FILTER_ERROR_RATE);
 BEGIN {
 	$BLOOM_FILTER_ERROR_RATE	= 0.1;
-	$VERSION	= '2.917_01';
+	$VERSION	= '2.202';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
@@ -88,7 +85,7 @@ sub query {
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -103,7 +100,7 @@ sub sse {
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
@@ -118,21 +115,6 @@ sub as_sparql {
 	return $string;
 }
 
-=item C<< as_hash >>
-
-Returns the query as a nested set of plain data structures (no objects).
-
-=cut
-
-sub as_hash {
-	my $self	= shift;
-	my $context	= shift;
-	return {
-		type 		=> lc($self->type),
-		pattern		=> $self->query->as_hash,
-	};
-}
-
 =item C<< type >>
 
 Returns the type of this algebra expression.
@@ -155,16 +137,16 @@ sub referenced_variables {
 	return @list;
 }
 
-=item C<< potentially_bound >>
+=item C<< binding_variables >>
 
 Returns a list of the variable names used in this algebra expression that will
 bind values during execution.
 
 =cut
 
-sub potentially_bound {
+sub binding_variables {
 	my $self	= shift;
-	return $self->query->pattern->potentially_bound;
+	return $self->query->pattern->binding_variables;
 }
 
 =item C<< definite_variables >>
