@@ -7,7 +7,7 @@ RDF::Query::Algebra::Triple - Algebra class for Triple patterns
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Triple version 2.201, released 30 January 2010.
+This document describes RDF::Query::Algebra::Triple version 2.202, released 30 January 2010.
 
 =cut
 
@@ -32,7 +32,7 @@ our ($VERSION);
 my %TRIPLE_LABELS;
 my @node_methods	= qw(subject predicate object);
 BEGIN {
-	$VERSION	= '2.201';
+	$VERSION	= '2.202';
 }
 
 ######################################################################
@@ -142,31 +142,6 @@ sub bf {
 	return $bf;
 }
 
-=item C<< fixup ( $query, $bridge, $base, \%namespaces ) >>
-
-Returns a new pattern that is ready for execution using the given bridge.
-This method replaces generic node objects with bridge-native objects.
-
-=cut
-
-sub fixup {
-	my $self	= shift;
-	my $class	= ref($self);
-	my $query	= shift;
-	my $bridge	= shift;
-	my $base	= shift;
-	my $ns		= shift;
-	
-	if (my $opt = $query->algebra_fixup( $self, $bridge, $base, $ns )) {
-		return $opt;
-	} else {
-		my @nodes	= $self->nodes;
-		@nodes	= map { $bridge->as_native( $_, $base, $ns ) } @nodes;
-		my $fixed	= $class->new( @nodes );
-		return $fixed;
-	}
-}
-
 =item C<< distinguish_bnode_variables >>
 
 Returns a new Quad object with blank nodes replaced by distinguished variables.
