@@ -7,13 +7,10 @@ RDF::Query::Plan::Extend - Executable query plan for Extends.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Extend version 2.917_01.
+This document describes RDF::Query::Plan::Extend version 2.202, released 30 January 2010.
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Plan> class.
-
 =over 4
 
 =cut
@@ -23,15 +20,14 @@ package RDF::Query::Plan::Extend;
 use strict;
 use warnings;
 use base qw(RDF::Query::Plan);
-use RDF::Query::Error qw(:try);
-use Scalar::Util qw(blessed refaddr);
-use Data::Dumper;
+
+use Scalar::Util qw(blessed);
 
 ######################################################################
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.917_01';
+	$VERSION	= '2.202';
 }
 
 ######################################################################
@@ -62,11 +58,8 @@ sub new {
 sub execute ($) {
 	my $self	= shift;
 	my $context	= shift;
-	$self->[0]{delegate}	= $context->delegate;
-	my $l		= Log::Log4perl->get_logger("rdf.query.plan.extend");
-	$l->trace( "executing extend plan: " . $self->sse );
 	if ($self->state == $self->OPEN) {
-		throw RDF::Query::Error::ExecutionError -text => "EXTEND plan can't be executed while already open";
+		throw RDF::Query::Error::ExecutionError -text => "PROJECT plan can't be executed while already open";
 	}
 	my $plan	= $self->[1];
 	$plan->execute( $context );
@@ -86,60 +79,44 @@ sub execute ($) {
 
 sub next {
 	my $self	= shift;
-	my $ctx		= $self->[0]{context};
 	unless ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "next() cannot be called on an un-open PROJECT";
 	}
 	
 	my $l		= Log::Log4perl->get_logger("rdf.query.plan.extend");
 	my $plan	= $self->[1];
-	while (1) {
-		my $result		= $plan->next;
-		unless (defined($result)) {
-			$l->trace("no remaining rows in extend");
-			if ($self->[1]->state == $self->[1]->OPEN) {
-				$self->[1]->close();
-			}
-			return;
+	my $row		= $plan->next;
+	unless (defined($row)) {
+		$l->trace("no remaining rows in extend");
+		if ($self->[1]->state == $self->[1]->OPEN) {
+			$self->[1]->close();
 		}
-		my $row			= RDF::Query::VariableBindings->new( { %$result } );
-		if ($l->is_trace) {
-			$l->trace( "extend on row $row" );
-		}
-		
-		my $keys	= $self->[2];
-		my $exprs	= $self->[3];
-		my $query	= $self->[0]{context}->query;
-		
-		local($query->{_query_row_cache})	= {};
-#		my $proj	= $row->project( @{ $keys } );
-		my $ok	= 1;
-		foreach my $e (@$exprs) {
-			my $name			= $e->name;
-			my $var_or_expr	= $e->expression;
-			if ($l->is_trace) {
-				$l->trace( "- extend alias " . $var_or_expr->sse . " -> $name" );
-			}
-			try {
-				my $value		= $query->var_or_expr_value( $row, $var_or_expr, $ctx );
-				if ($l->is_trace) {
-					$l->trace( "- extend value $name -> $value" );
-				}
-				$row->{ $name }	= $value;
-			} catch RDF::Query::Error with {
-				$l->trace( "- evaluating extend expression resulted in an error; dropping the variable binding" );
-			} otherwise {
-				my $e	= shift;
-				warn 'exception caught in Extend(): ' . Dumper($e);
-			};
-		}
-		next unless ($ok);
-		$l->trace( "Extended result: $row" );
-		if (my $d = $self->delegate) {
-			$d->log_result( $self, $row );
-		}
-		return $row;
+		return;
 	}
+	if ($l->is_trace) {
+		$l->trace( "extend on row $row" );
+	}
+	
+	my $keys	= $self->[2];
+	my $exprs	= $self->[3];
+	my $query	= $self->[0]{context}->query;
+	my $bridge	= $self->[0]{context}->model;
+	
+	my $proj	= $row->project( @{ $keys } );
+	foreach my $e (@$exprs) {
+		my $name			= $e->name;
+		my $var_or_expr	= $e->expression;
+		if ($l->is_trace) {
+			$l->trace( "- extend alias " . $var_or_expr->sse . " -> $name" );
+		}
+		my $value		= $query->var_or_expr_value( $bridge, $row, $var_or_expr );
+		if ($l->is_trace) {
+			$l->trace( "- extend value $name -> $value" );
+		}
+		$row->{ $name }	= $value;
+	}
+	
+	return $row;
 }
 
 =item C<< close >>
@@ -242,30 +219,6 @@ sub graph {
 	return "$self";
 }
 
-=item C<< explain >>
-
-Returns a string serialization of the plan appropriate for display on the
-command line.
-
-=cut
-
-sub explain {
-	my $self	= shift;
-	my $s		= shift;
-	my $count	= shift;
-	my $indent	= $s x $count;
-	my $type	= $self->plan_node_name;
-	my $string	= sprintf("%s%s (0x%x)\n", $indent, $type, refaddr($self));
-	$string		.= "${indent}${s}vars:\n";
-	my @vars	= map { RDF::Query::Node::Variable->new( $_ ) } @{$self->[2]};
-	my @exprs	= @{$self->[3]};
-	foreach my $e (@vars, @exprs) {
-		$string		.= $e->explain($s, $count+2);
-	}
-	$string		.= $self->pattern->explain( $s, $count+1 );
-	return $string;
-}
-
 
 
 1;
